@@ -13,7 +13,7 @@ from flexget import validator
 log = logging.getLogger('piratebay')
 
 TLDS = "com|org|sx|se"
-CUR_TLD = "sx"
+CUR_TLD = "ac"
 
 URL_MATCH = re.compile("^http://(?:torrents\.)?thepiratebay\.(?:%s)/.*$" % TLDS)
 URL_SEARCH = re.compile("^http://thepiratebay\.(?:%s)/search/.*$" % TLDS)
